/* Multibyte characters: macros for single-byte encodings.
   Copyright (C) 2001, 2007 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */

/* Written by Bruno Haible <bruno@clisp.org>.  */

/* The macros in this file implement operations on 8-bit characters.  They
   are to be used when MB_CUR_MAX == 1.  The same macros are defined in
   mbchar_multi.h for multi-byte characters, for use when MB_CUR_MAX > 1.
 */

#ifndef _MBCHAR_8BIT_H
#define _MBCHAR_8BIT_H 1

#include <ctype.h>
#include <wchar.h>

static inline int
mbchar_8bit_width (char c)
{
  int w = wcwidth (btowc ((unsigned char) c));
  /* For unprintable characters, arbitrarily return 0 for control characters
     and 1 otherwise.  */
  return (w >= 0 ? w : iscntrl ((unsigned char) c) ? 0 : 1);
}

#endif /* _MBCHAR_8BIT_H */
/* Now the macros that will be undefined in mbchar_undef.h.  */

/* The character type.  */
#define MB_CHAR char

/* Accessing the byte sequence.  */
#define MB_PTR(c) &(c)
#define MB_LEN(c) 1

/* Comparison.  */
#define MB_ISEQ(c, sc) ((c) == (sc))
#define MB_ISNUL(c) ((c) == '\0')
#define MB_CMP(c1, c2) \
  ((int) (unsigned char) (c1) - (int) (unsigned char) (c2))
#define MB_CASECMP(c1, c2) \
  ((int) (unsigned char) tolower ((unsigned char) (c1)) \
   - (int) (unsigned char) tolower ((unsigned char) (c2)))
#define MB_EQUAL(c1, c2) \
  ((c1) == (c2))
#define MB_CASEEQUAL(c1, c2) \
  ((unsigned char) tolower ((unsigned char) (c1)) \
   == (unsigned char) tolower ((unsigned char) (c2)))

/* <ctype.h>, <wctype.h> classification.  */
#define MB_ISASCII(c) isascii ((unsigned char) (c))
#define MB_ISALNUM(c) isalnum ((unsigned char) (c))
#define MB_ISALPHA(c) isalpha ((unsigned char) (c))
#define MB_ISBLANK(c) isblank ((unsigned char) (c))
#define MB_ISCNTRL(c) iscntrl ((unsigned char) (c))
#define MB_ISDIGIT(c) isdigit ((unsigned char) (c))
#define MB_ISGRAPH(c) isgraph ((unsigned char) (c))
#define MB_ISLOWER(c) islower ((unsigned char) (c))
#define MB_ISPRINT(c) isprint ((unsigned char) (c))
#define MB_ISPUNCT(c) ispunct ((unsigned char) (c))
#define MB_ISSPACE(c) isspace ((unsigned char) (c))
#define MB_ISUPPER(c) isupper ((unsigned char) (c))
#define MB_ISXDIGIT(c) isxdigit ((unsigned char) (c))

/* Extra <wchar.h> function.  */
#if 0 /* too simplistic, doesn't work with ISO-8859-6, ISO-8859-8, TIS-620 */
#define MB_WIDTH(c) 1
#else
#define MB_WIDTH(c) mbchar_8bit_width (c)
#endif

/* Output.  */
#define MB_PUTC(c, stream) putc ((unsigned char) (c), (stream))

/* Assignment.  */
#define MB_SETASCII(c, sc) ((c) = (sc))

/* Copy.  */
#define MB_COPY(new_c, old_c) ((new_c) = (old_c))
