/* Multibyte characters: macros for multi-byte encodings.
   Copyright (C) 2001, 2007 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */

/* Written by Bruno Haible <bruno@clisp.org>.  */

/* The macros in this file implement operations on multi-byte characters.
   They are to be used when MB_CUR_MAX > 1.  The same macros are defined in
   mbchar_8bit.h for 8-bit characters, for use when MB_CUR_MAX == 1.

   MB_PTR (mbc)
     return a pointer to the beginning of the multibyte sequence.

   MB_LEN (mbc)
     returns the number of bytes occupied by the multibyte sequence.
     Always > 0.

   MB_ISEQ (mbc, sc)
     returns true if mbc is the standard ASCII character sc.

   MB_ISNUL (mbc)
     returns true if mbc is the nul character.

   MB_CMP (mbc1, mbc2)
     returns a positive, zero, or negative value depending on whether mbc1
     sorts after, same or before mbc2.

   MB_CASECMP (mbc1, mbc2)
     returns a positive, zero, or negative value depending on whether mbc1
     sorts after, same or before mbc2, modulo upper/lowercase conversion.

   MB_EQUAL (mbc1, mbc2)
     returns true if mbc1 and mbc2 are equal.

   MB_CASEEQUAL (mbc1, mbc2)
     returns true if mbc1 and mbc2 are equal modulo upper/lowercase conversion.

   MB_ISALNUM (mbc)
     returns true if mbc is alphanumeric.

   MB_ISALPHA (mbc)
     returns true if mbc is alphabetic.

   MB_ISASCII (mbc)
     returns true if mbc is plain ASCII.

   MB_ISBLANK (mbc)
     returns true if mbc is a blank.

   MB_ISCNTRL (mbc)
     returns true if mbc is a control character.

   MB_ISDIGIT (mbc)
     returns true if mbc is a decimal digit.

   MB_ISGRAPH (mbc)
     returns true if mbc is a graphic character.

   MB_ISLOWER (mbc)
     returns true if mbc is lowercase.

   MB_ISPRINT (mbc)
     returns true if mbc is a printable character.

   MB_ISPUNCT (mbc)
     returns true if mbc is a punctuation character.

   MB_ISSPACE (mbc)
     returns true if mbc is a space character.

   MB_ISUPPER (mbc)
     returns true if mbc is uppercase.

   MB_ISXDIGIT (mbc)
     returns true if mbc is a hexadecimal digit.

   MB_WIDTH (mbc)
     returns the number of columns on the output device occupied by mbc.
     Always >= 0.

   MB_PUTC (mbc, stream)
     outputs mbc on stream, a byte oriented FILE stream opened for output.

   MB_SETASCII (mbc, sc)
     assigns the standard ASCII character sc to mbc.

   Here are the function prototypes of the macros.

   extern const char *	MB_PTR (const MB_CHAR mbc);
   extern size_t	MB_LEN (const MB_CHAR mbc);
   extern bool		MB_ISEQ (const MB_CHAR mbc, char sc);
   extern bool		MB_ISNUL (const MB_CHAR mbc);
   extern int		MB_CMP (const MB_CHAR mbc1, const MB_CHAR mbc2);
   extern int		MB_CASECMP (const MB_CHAR mbc1, const MB_CHAR mbc2);
   extern bool		MB_EQUAL (const MB_CHAR mbc1, const MB_CHAR mbc2);
   extern bool		MB_CASEEQUAL (const MB_CHAR mbc1, const MB_CHAR mbc2);
   extern bool		MB_ISALNUM (const MB_CHAR mbc);
   extern bool		MB_ISALPHA (const MB_CHAR mbc);
   extern bool		MB_ISASCII (const MB_CHAR mbc);
   extern bool		MB_ISBLANK (const MB_CHAR mbc);
   extern bool		MB_ISCNTRL (const MB_CHAR mbc);
   extern bool		MB_ISDIGIT (const MB_CHAR mbc);
   extern bool		MB_ISGRAPH (const MB_CHAR mbc);
   extern bool		MB_ISLOWER (const MB_CHAR mbc);
   extern bool		MB_ISPRINT (const MB_CHAR mbc);
   extern bool		MB_ISPUNCT (const MB_CHAR mbc);
   extern bool		MB_ISSPACE (const MB_CHAR mbc);
   extern bool		MB_ISUPPER (const MB_CHAR mbc);
   extern bool		MB_ISXDIGIT (const MB_CHAR mbc);
   extern int		MB_WIDTH (const MB_CHAR mbc);
   extern void		MB_PUTC (const MB_CHAR mbc, FILE *stream);
   extern void		MB_SETASCII (MB_CHAR mbc, char sc);
 */

#ifndef _MBCHAR_MULTI_H
#define _MBCHAR_MULTI_H 1

#include "mbchar.h"

#endif /* _MBCHAR_MULTI_H */
/* Now the macros that will be undefined in mbchar_undef.h.  */

/* The character type.  */
#define MB_CHAR mbchar_t

/* Accessing the byte sequence.  */
#define MB_PTR(mbc) mb_ptr (mbc)
#define MB_LEN(mbc) mb_len (mbc)

/* Comparison.  */
#define MB_ISEQ(mbc, sc) mb_iseq (mbc, sc)
#define MB_ISNUL(mbc) mb_isnul (mbc)
#define MB_CMP(mbc1, mbc2) mb_cmp (mbc1, mbc2)
#define MB_CASECMP(mbc1, mbc2) mb_casecmp (mbc1, mbc2)
#define MB_EQUAL(mbc1, mbc2) mb_equal (mbc1, mbc2)
#define MB_CASEEQUAL(mbc1, mbc2) mb_caseequal (mbc1, mbc2)

/* <ctype.h>, <wctype.h> classification.  */
#define MB_ISASCII(mbc) mb_isascii (mbc)
#define MB_ISALNUM(mbc) mb_isalnum (mbc)
#define MB_ISALPHA(mbc) mb_isalpha (mbc)
#define MB_ISBLANK(mbc) mb_isblank (mbc)
#define MB_ISCNTRL(mbc) mb_iscntrl (mbc)
#define MB_ISDIGIT(mbc) mb_isdigit (mbc)
#define MB_ISGRAPH(mbc) mb_isgraph (mbc)
#define MB_ISLOWER(mbc) mb_islower (mbc)
#define MB_ISPRINT(mbc) mb_isprint (mbc)
#define MB_ISPUNCT(mbc) mb_ispunct (mbc)
#define MB_ISSPACE(mbc) mb_isspace (mbc)
#define MB_ISUPPER(mbc) mb_isupper (mbc)
#define MB_ISXDIGIT(mbc) mb_isxdigit (mbc)

/* Extra <wchar.h> function.  */
#define MB_WIDTH(mbc) mb_width (mbc)

/* Output.  */
#define MB_PUTC(mbc, stream) mb_putc (mbc, stream)

/* Assignment.  */
#define MB_SETASCII(mbc, sc) mb_setascii (&(mbc), sc)

/* Copy.  */
#define MB_COPY(new_mbc, old_mbc) mb_copy (&(new_mbc), &(old_mbc))
