/* Multibyte character I/O: macros for multi-byte encodings.
   Copyright (C) 2001, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */

/* Written by Mitsuru Chinen <mchinen@yamato.ibm.com>
   and Bruno Haible <bruno@clisp.org>.  */

/* The macros in this file implement multi-byte character input from a
   stream.  They are to be used when MB_CUR_MAX > 1.  The same macros are
   defined in mbfile_8bit.h for input in an 8-bit encoding, for use when
   MB_CUR_MAX == 1.

   MB_FILE
     expands to the type for multibyte character input stream, usable for
     variable declarations.

   MBF_CHAR
     expands to the type for multibyte character or EOF, usable for
     variable declarations.

   MBF_INIT (mbf, stream)
     initializes the MB_FILE for reading from stream.

   MBF_GETC (mbc, mbf)
     reads the next multibyte character from mbf and stores it in mbc.

   MB_ISEOF (mbc)
     returns true if mbc represents the EOF value.

   Here are the function prototypes of the macros.

   extern void		MBF_INIT (MB_FILE mbf, FILE *stream);
   extern void		MBF_GETC (MBF_CHAR mbc, MB_FILE mbf);
   extern bool		MB_ISEOF (const MBF_CHAR mbc);
 */

#ifndef _MBFILE_MULTI_H
#define _MBFILE_MULTI_H 1

#include "mbfile.h"

#endif /* _MBFILE_MULTI_H */
/* Now the macros that will be undefined in mbfile_undef.h.  */

#include "mbchar_multi.h"

#define MB_FILE mb_file_t
#define MBF_CHAR mbf_char_t
#define MBF_INIT(mbf, stream) mbf_init (mbf, stream)
#define MBF_GETC(mbc, mbf) mbf_getc (mbc, mbf)
#define MBF_UNGETC(mbc, mbf) mbf_ungetc (mbc, mbf)
#define MB_ISEOF(mbc) mb_iseof (mbc)
