/* Iterating through multibyte strings: macros for single-byte encodings.
   Copyright (C) 2001, 2007 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */

/* Written by Bruno Haible <bruno@clisp.org>.  */

/* The macros in this file implement forward iteration through an
   8-bit string.  They are to be used when MB_CUR_MAX == 1.  The same
   macros are defined in mbiter_multi.h for iteration through a multi-byte
   string, for use when MB_CUR_MAX > 1.
 */

#ifndef _MBITER_8BIT_H
#define _MBITER_8BIT_H 1

struct mbiter_8bit
{
  const char *ptr;	/* pointer to current character */
  const char *limit;	/* pointer to end of string */
  char c;		/* after MBI_NEXT: the current character */
};

#endif /* _MBITER_8BIT_H */
/* Now the macros that will be undefined in mbiter_undef.h.  */

#include "mbchar_8bit.h"

/* Iteration macros.  */
#define MBI_ITERATOR struct mbiter_8bit
#define MBI_INIT(iter, startptr, length) \
  ((iter).ptr = (startptr), (iter).limit = (iter).ptr + (length))
#define MBI_AVAIL(iter) \
  ((iter).ptr < (iter).limit && (((iter).c = *(iter).ptr), true))
#define MBI_ADVANCE(iter) \
  ((iter).ptr++)

/* Access to the current character.  */
#define MBI_CUR(iter) ((iter).c)
#define MBI_CUR_PTR(iter) ((iter).ptr)

/* Relocation.  */
#define MBI_RELOC(iter, ptrdiff) (void) ((iter).ptr += (ptrdiff))

/* Copy.  */
#define MBI_COPY(new, old) ((new) = (old))
