/* Iterating through multibyte strings: macros for single-byte encodings.
   Copyright (C) 2001, 2007 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */

/* Written by Bruno Haible <bruno@clisp.org>.  */

/* The macros in this file implement forward iteration through an
   8-bit string.  They are to be used when MB_CUR_MAX == 1.  The same
   macros are defined in mbuiter_multi.h for iteration through a multi-byte
   string, for use when MB_CUR_MAX > 1.
 */

#ifndef _MBUITER_8BIT_H
#define _MBUITER_8BIT_H 1

struct mbuiter_8bit
{
  const char *ptr;	/* pointer to current character */
  char c;		/* after MBUI_NEXT: the current character */
};

#endif /* _MBUITER_8BIT_H */
/* Now the macros that will be undefined in mbuiter_undef.h.  */

#include "mbchar_8bit.h"

/* Iteration macros.  */
#define MBUI_ITERATOR struct mbuiter_8bit
#define MBUI_INIT(iter, startptr) \
  ((iter).ptr = (startptr))
#define MBUI_AVAIL(iter) \
  (*(iter).ptr != '\0' && (((iter).c = *(iter).ptr), true))
#define MBUI_ADVANCE(iter) \
  ((iter).ptr++)

/* Access to the current character.  */
#define MBUI_CUR(iter) ((iter).c)
#define MBUI_CUR_PTR(iter) ((iter).ptr)

/* Relocation.  */
#define MBUI_RELOC(iter, ptrdiff) (void) ((iter).ptr += (ptrdiff))

/* Copy.  */
#define MBUI_COPY(new, old) ((new) = (old))
